import React, { useState, useEffect, useRef } from "react";
import http from '@src/http';
import { Modal, Image, message } from "antd";
import { qwGetQrCode } from '@src/http/api';

interface QrCodeData {
  qrcode: string;
  uuid: string;
  ttl: number;
  key: string;
}

interface QrCodeModalProps {
  visible: boolean;
  onClose: () => void;
  title: string;
  vid?: string; // 可选参数，用于登录时传入
  onSuccess?: (data: QrCodeData) => void; // 可选回调，用于处理成功获取二维码后的操作
}

const QrCodeModal: React.FC<QrCodeModalProps> = ({ 
  visible, 
  onClose, 
  title, 
  vid,
  onSuccess 
}) => {
  const [loading, setLoading] = useState(false);
  const [qrCodeData, setQrCodeData] = useState<QrCodeData | null>(null);
  const [countdown, setCountdown] = useState<number>(0);
  const timerRef = useRef<NodeJS.Timeout | null>(null);

  // 获取二维码
  const fetchQrCode = async () => {
    try {
      setLoading(true);
      // 根据是否有 vid 参数决定是添加账号还是登录
      const res = await http.post<QrCodeData>(qwGetQrCode, { vid });

      if (res.success) {
        setQrCodeData(res.data);
        // 设置倒计时初始值
        setCountdown(res.data.ttl);
        // 如果有成功回调，则调用
        if (onSuccess) {
          onSuccess(res.data);
        }
      } else {
        message.error(res.msg || '获取二维码失败');
      }
    } catch {
      message.error('获取二维码失败');
    } finally {
      setLoading(false);
    }
  };

  // 启动倒计时
  useEffect(() => {
    if (countdown > 0) {
      timerRef.current = setInterval(() => {
        setCountdown(prev => {
          if (prev <= 1) {
            // 倒计时结束，清除定时器
            if (timerRef.current) {
              clearInterval(timerRef.current);
              timerRef.current = null;
            }
            return 0;
          }
          return prev - 1;
        });
      }, 1000);
    }

    return () => {
      // 组件卸载或依赖项变化时清除定时器
      if (timerRef.current) {
        clearInterval(timerRef.current);
        timerRef.current = null;
      }
    };
  }, [countdown]);

  // 当弹窗显示时获取二维码
  useEffect(() => {
    if (visible) {
      fetchQrCode();
    } else {
      // 关闭弹窗时清空数据和定时器
      setQrCodeData(null);
      setCountdown(0);
      if (timerRef.current) {
        clearInterval(timerRef.current);
        timerRef.current = null;
      }
    }
  }, [visible, vid]);

  // 处理弹窗关闭
  const handleClose = () => {
    onClose();
  };

  return (
    <Modal
      title={title}
      open={visible}
      onCancel={handleClose}
      footer={null}
      destroyOnClose
    >
      {qrCodeData && (
        <div className="flex flex-col items-center">
          <Image
            src={qrCodeData.qrcode}
            alt="二维码"
            width={200}
            preview={false}
            loading={loading ? 'lazy' : undefined}
          />
          <p className="mt-4 text-center">请使用企业微信扫描二维码</p>
          <p className="text-center text-gray-500">
            二维码有效期 {countdown} 秒
            {countdown === 0 && (
              <span className="text-red-500 ml-2">(已过期，请关闭后重试)</span>
            )}
          </p>
        </div>
      )}
    </Modal>
  );
};

export default QrCodeModal;
